# diy

[![codecov](https://codecov.io/github/NiclasvanEyk/diy/graph/badge.svg?token=7GM4SUNZUF)](https://codecov.io/github/NiclasvanEyk/diy)

A dependency injection container that heavily utilizes Pythons type annotations.

> **Work In Progress**. Will force push main. Not production ready!
